@@ -1,4 +1,4 @@
-module Hledger.Interest.Rate ( Rate, perAnno, constant, bgb288, ingDiba ) where
+module Hledger.Interest.Rate ( Rate, perAnno, constant, bgb288, ingDiba, db24 ) where
 
 import Data.Time.Calendar
 import Data.Time.Calendar.OrdinalDate
@@ -45,6 +45,21 @@ basiszinsTable =
   , (day 2010 07 01, day 2010 12 31,  12 / 10000)
   , (day 2011 01 01, day 2011 06 30,  12 / 10000)
   , (day 2011 07 01, day 2999 12 31,  37 / 10000)
+  , (day 2011 01 01, day 2011 06 30,  12 / 10000)
+  , (day 2011 07 01, day 2011 12 31,  37 / 10000)
+  , (day 2012 01 01, day 2012 06 30,  12 / 10000)
+  , (day 2012 07 01, day 2012 12 31,  12 / 10000)
+  , (day 2013 01 01, day 2013 06 30, -13 / 10000)
+  , (day 2013 07 01, day 2013 12 31, -38 / 10000)
+  , (day 2014 01 01, day 2014 06 30, -63 / 10000)
+  , (day 2014 07 01, day 2014 12 31, -73 / 10000)
+  , (day 2015 01 01, day 2015 06 30, -83 / 10000)
+  , (day 2015 07 01, day 2015 12 31, -83 / 10000)
+  , (day 2016 01 01, day 2016 06 30, -83 / 10000)
+  , (day 2016 07 01, day 2016 12 31, -88 / 10000)
+  , (day 2017 01 01, day 2017 06 30, -88 / 10000)
+  , (day 2017 07 01, day 2017 12 31, -88 / 10000)
+  , (day 2018 01 01, day 2018 06 30, -88 / 10000)
   ]
 
 ingDiba :: Rate
@@ -59,3 +74,14 @@ ingDibaTable =
   , (day 2011 01 01, day 2011 07 14, 150 / 10000)
   , (day 2011 07 15, day 2999 12 31, 175 / 10000)
   ]
+
+db24 :: Rate
+db24 date = (to, p)
+  where
+    (_,to,p) = head (dropWhile (\(_,to',_) -> to' < date) db24Table)
+
+db24Table :: [(Day, Day, Decimal)]
+db24Table =
+  [ (day 2000 10 06, day 2010 09 15, 638 / 10000)
+  , (day 2010 09 16, day 2999 12 31, 415 / 10000)
+  ]
